@@ -433,7 +433,11 @@
 	funcpascpm = res
 
 	do k=1,ng
-		cumulhaz(k)=res1(k)
+		if (AG.eq.1) then
+			cumulhaz(k)=res1(k)-res3(k)
+		else 
+			cumulhaz(k)=res1(k)
+		endif
 	end do
 
 123     continue
